# Overview

## What does this package do?
This package is designed to support various methods for statistical analysis. In particular, we hope to offer tools for computing Shapley effects and Proportional Marginal Effects (PMEs) for a variety of models.

## Current features
The *gsapme* package is a work in progress. We currently support the following features:

1. Computation of conditional multivariate normal distributions (`conditional_mvn`)
2. Conditional simulations from a multivariate normal distribution (`cond_sim`)
3. Covariance matrix construction helper function (`generate_cov_matrix`)